# arpes.utilities.math module

**arpes.utilities.math.derivative(f, arg\_idx=0)**

> Defines a simple midpoint derivative

**arpes.utilities.math.fermi\_distribution(energy, temperature)**

> Expects energy in eV and temperature in Kelvin.

**arpes.utilities.math.inv\_fermi\_distribution(energy, temperature,
mu=0)**

> Expects energy in eV and temperature in Kelvin.

**arpes.utilities.math.polarization(up, down)**

**arpes.utilities.math.propagate\_statistical\_error(f)**

**arpes.utilities.math.shift\_by(arr, value, axis=0,
by\_axis=0,**kwargs)\*\*
